Class: CoreExt::Callbacks::CallbackSequence
- Defined in:
- lib/core_ext/callbacks.rb
Overview
Execute before and after filters in a sequence instead of chaining them with nested lambda calls, see: github.com/rails/rails/issues/18011
Instance Method Summary collapse
- #after(&after) ⇒ Object
- #around(&around) ⇒ Object
- #before(&before) ⇒ Object
- #call(arg) ⇒ Object
-
#initialize(&call) ⇒ CallbackSequence
constructor
A new instance of CallbackSequence.
Constructor Details
#initialize(&call) ⇒ CallbackSequence
Returns a new instance of CallbackSequence.
417 418 419 420 421 |
# File 'lib/core_ext/callbacks.rb', line 417 def initialize(&call) @call = call @before = [] @after = [] end |
Instance Method Details
#after(&after) ⇒ Object
428 429 430 431 |
# File 'lib/core_ext/callbacks.rb', line 428 def after(&after) @after.push(after) self end |
#around(&around) ⇒ Object
433 434 435 436 437 438 439 |
# File 'lib/core_ext/callbacks.rb', line 433 def around(&around) CallbackSequence.new do |arg| around.call(arg) { self.call(arg) } end end |
#before(&before) ⇒ Object
423 424 425 426 |
# File 'lib/core_ext/callbacks.rb', line 423 def before(&before) @before.unshift(before) self end |
#call(arg) ⇒ Object
441 442 443 444 445 446 |
# File 'lib/core_ext/callbacks.rb', line 441 def call(arg) @before.each { |b| b.call(arg) } value = @call.call(arg) @after.each { |a| a.call(arg) } value end |