Module: CoreExt::Concern

Overview

A typical module looks like this:

module M
def self.included(base)
  base.extend ClassMethods
  base.class_eval do
    scope :disabled, -> { where(disabled: true) }
  end
end

module ClassMethods
  ...
end
end

By using CoreExt::Concern the above module could instead be written as:

require 'core_ext/concern'

module M
extend CoreExt::Concern

included do
  scope :disabled, -> { where(disabled: true) }
end

class_methods do
  ...
end
end

Moreover, it gracefully handles module dependencies. Given a Foo module and a Bar module which depends on the former, we would typically write the following:

module Foo
def self.included(base)
  base.class_eval do
    def self.method_injected_by_foo
      ...
    end
  end
end
end

module Bar
def self.included(base)
  base.method_injected_by_foo
end
end

class Host
include Foo # We need to include this dependency for Bar
include Bar # Bar is the module that Host really needs
end

But why should Host care about +Bar+'s dependencies, namely Foo? We could try to hide these from Host directly including Foo in Bar:

module Bar
include Foo
def self.included(base)
  base.method_injected_by_foo
end
end

class Host
include Bar
end

Unfortunately this won't work, since when Foo is included, its base is the Bar module, not the Host class. With CoreExt::Concern, module dependencies are properly resolved:

require 'core_ext/concern'

module Foo
extend CoreExt::Concern
included do
  def self.method_injected_by_foo
    ...
  end
end
end

module Bar
extend CoreExt::Concern
include Foo

included do
  self.method_injected_by_foo
end
end

class Host
include Bar # It works, now Bar takes care of its dependencies
end

Defined Under Namespace

Classes: MultipleIncludedBlocks

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.extended(base) ⇒ Object

:nodoc:



107
108
109
# File 'lib/core_ext/concern.rb', line 107

def self.extended(base) #:nodoc:
  base.instance_variable_set(:@_dependencies, [])
end

Instance Method Details

#append_features(base) ⇒ Object



111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/core_ext/concern.rb', line 111

def append_features(base)
  if base.instance_variable_defined?(:@_dependencies)
    base.instance_variable_get(:@_dependencies) << self
    return false
  else
    return false if base < self
    @_dependencies.each { |dep| base.include(dep) }
    super
    base.extend const_get(:ClassMethods) if const_defined?(:ClassMethods)
    base.class_eval(&@_included_block) if instance_variable_defined?(:@_included_block)
  end
end

#class_methods(&class_methods_module_definition) ⇒ Object



134
135
136
137
138
139
140
# File 'lib/core_ext/concern.rb', line 134

def class_methods(&class_methods_module_definition)
  mod = const_defined?(:ClassMethods, false) ?
    const_get(:ClassMethods) :
    const_set(:ClassMethods, Module.new)

  mod.module_eval(&class_methods_module_definition)
end

#included(base = nil, &block) ⇒ Object



124
125
126
127
128
129
130
131
132
# File 'lib/core_ext/concern.rb', line 124

def included(base = nil, &block)
  if base.nil?
    raise MultipleIncludedBlocks if instance_variable_defined?(:@_included_block)

    @_included_block = block
  else
    super
  end
end