Method: CoreExt::Inflector#titleize

Defined in:
lib/core_ext/inflector/methods.rb

#titleize(word) ⇒ Object

Capitalizes all the words and replaces some characters in the string to create a nicer looking title. titleize is meant for creating pretty output. It is not used in the Rails internals.

titleize is also aliased as titlecase.

titleize('man from the boondocks')   # => "Man From The Boondocks"
titleize('x-men: the last stand')    # => "X Men: The Last Stand"
titleize('TheManWithoutAPast')       # => "The Man Without A Past"
titleize('raiders_of_the_lost_ark')  # => "Raiders Of The Lost Ark"


153
154
155
# File 'lib/core_ext/inflector/methods.rb', line 153

def titleize(word)
  humanize(underscore(word)).gsub(/\b(?<!['’`])[a-z]/) { |match| match.capitalize }
end