Method: String#tableize
- Defined in:
- lib/core_ext/string/inflections.rb
#tableize ⇒ Object
Creates the name of a table like Rails does for models to table names. This method uses the pluralize method on the last word in the string.
'RawScaledScorer'.tableize # => "raw_scaled_scorers"
'ham_and_egg'.tableize # => "ham_and_eggs"
'fancyCategory'.tableize # => "fancy_categories"
195 196 197 |
# File 'lib/core_ext/string/inflections.rb', line 195 def tableize CoreExt::Inflector.tableize(self) end |